@@ -15,14 +15,11 @@
  */
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
+
 /**
- * @file globus_ftp_client_handle.c FTP Handle Manipulation.
- *
- * $RCSfile: globus_ftp_client_handle.c,v $
- * $Revision: 1.48 $
- * $Date: 2011/05/19 04:03:42 $
+ * @file globus_ftp_client_handle.c
+ * @brief FTP Handle Manipulation.
  */
-#endif
 
 #include "globus_i_ftp_client.h"
 #include "globus_xio.h"
@@ -30,7 +27,6 @@
 
 #include <string.h>
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
  * Target cache search predicate closure.
  * @internal
@@ -333,7 +329,7 @@ globus_ftp_client_handle_init(
     i_handle->checksum_offset = 0;
     i_handle->checksum_length = -1;
     i_handle->checksum = GLOBUS_NULL;
-    i_handle->source_pasv = (globus_libc_getenv("GLOBUS_FTP_CLIENT_SOURCE_PASV") != NULL);
+    i_handle->source_pasv = (getenv("GLOBUS_FTP_CLIENT_SOURCE_PASV") != NULL);
     globus_fifo_init(&i_handle->src_op_queue);
     globus_fifo_init(&i_handle->dst_op_queue);
     globus_fifo_init(&i_handle->src_response_pending_queue);
@@ -1001,7 +997,7 @@ globus_l_ftp_client_target_new(
         }
 
 /*
-        remote_program = globus_libc_getenv("GLOBUS_REMOTE_SSHFTP");
+        remote_program = getenv("GLOBUS_REMOTE_SSHFTP");
         if(remote_program == NULL)
         {
             remote_program = "/etc/grid-security/sshftp";
